@@ -1,5 +1,10 @@
 ## ----setup, include = FALSE----------------------------------------------
-knitr::opts_chunk$set(collapse = T, comment = "#")
+knitr::opts_chunk$set(
+  collapse = TRUE,
+  comment = "#>",
+  fig.width = 6,
+  fig.height = 6
+)
 
 ## ---- echo = TRUE--------------------------------------------------------
 citation("brglm2")
